@@ -1,7 +1,7 @@
 //
 // BeagleDaemon.cs
 //
-// Copyright (C) 2004 Novell, Inc.
+// Copyright (C) 2004-2006 Novell, Inc.
 //
 
 //
@@ -97,8 +97,8 @@ namespace Beagle.Daemon {
 		{
 			string usage =
 				"beagled: The daemon to the Beagle search system.\n" +
-				"Web page: http://www.gnome.org/projects/beagle\n" +
-				"Copyright (C) 2004-2005 Novell, Inc.\n\n";
+				"Web page: http://beagle-project.org\n" +
+				"Copyright (C) 2004-2006 Novell, Inc.\n\n";
 
 			usage +=
 				"Usage: beagled [OPTIONS]\n\n" +
@@ -108,7 +108,8 @@ namespace Beagle.Daemon {
 				"  --replace\t\tReplace a running daemon with a new instance.\n" +
 				"  --debug\t\tWrite out debugging information.\n" +
 				"  --debug-memory\tWrite out debugging information about memory use.\n" +
-				"  --indexing-test-mode\tRun in foreground, and exit when fully indexed.\n" + 
+				"  --indexing-test-mode\tRun in foreground, and exit when fully indexed.\n" +
+				"  --indexing-delay\tTime to wait before indexing.  (Default 60 seconds)\n" +
 				"  --deny-backend\tDeny a specific backend.\n" +
 				"  --allow-backend\tAllow a specific backend.\n" +
 				"  --list-backends\tList all the available backends.\n" +
@@ -220,6 +221,8 @@ namespace Beagle.Daemon {
 
 		public static void DoMain (string[] args)
 		{
+			SystemInformation.SetProcessName ("beagled");
+
 			// Process the command-line arguments
 			bool arg_debug = false;
 			bool arg_debug_memory = false;
@@ -300,6 +303,19 @@ namespace Beagle.Daemon {
 					arg_disable_scheduler = true;
 					break;
 
+				case "--indexing-delay":
+					if (next_arg != null) {
+						try {
+							QueryDriver.IndexingDelay = Int32.Parse (next_arg);
+						} catch {
+							Console.WriteLine ("'{0}' is not a valid number of seconds", next_arg);
+							Environment.Exit (1);
+						}
+					}
+
+					++i;
+					break;
+
 				case "--autostarted":
 					if (! Conf.Searching.Autostart) {
 						Console.WriteLine ("Autostarting is disabled, not starting");
@@ -329,7 +345,8 @@ namespace Beagle.Daemon {
 					break;				
 #endif 
 				default:
-					Console.WriteLine ("Ignoring unknown argument '{0}'", arg);
+					Console.WriteLine ("Unknown argument '{0}'", arg);
+					Environment.Exit (1);
 					break;
 
 				}
@@ -341,9 +358,12 @@ namespace Beagle.Daemon {
 				
 
 			// Bail out if we are trying to run as root
-			if (Environment.UserName == "root") {
-				Console.WriteLine ("You can not run beagle as root.");
-				Console.WriteLine ("Beagle is designed to be run from your own user account.");
+			if (Environment.UserName == "root" && ! Conf.Daemon.AllowRoot) {
+				Console.WriteLine ("You can not run beagle as root.  Beagle is designed to run from your own");
+				Console.WriteLine ("user account.  If you want to create multiuser or system-wide indexes, use");
+				Console.WriteLine ("the beagle-build-index tool.");
+				Console.WriteLine ();
+				Console.WriteLine ("You can override this setting using the beagle-config or beagle-settings tools.");
 				Environment.Exit (-1);
 			}
 
@@ -358,13 +378,15 @@ namespace Beagle.Daemon {
 					arg_fg);
 
 			Logger.Log.Info ("Starting Beagle Daemon (version {0})", ExternalStringsHack.Version);
+
+			Logger.Log.Info ("Running on {0}", SystemInformation.MonoRuntimeVersion);
 			
 			Logger.Log.Debug ("Command Line: {0}",
 					  Environment.CommandLine != null ? Environment.CommandLine : "(null)");
 
 			if (! ExtendedAttribute.Supported) {
 				Logger.Log.Warn ("Extended attributes are not supported on this filesystem.  " +
-						 "Many search backends will not be available");
+						 "Performance will suffer as a result.");
 			}
 
 			// Start our memory-logging thread
