@@ -370,9 +370,9 @@ namespace Beagle.Daemon.KMailQueryable {
 			indexable.MimeType = "message/rfc822";
 			indexable.CacheContent = false;
 
-			indexable.AddProperty (Property.NewKeyword ("fixme:client", "kmail"));
-			indexable.AddProperty (Property.NewKeyword ("fixme:account", account_name));
-                        indexable.AddProperty (Property.NewKeyword ("fixme:folder", folder));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "kmail"));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:account", account_name));
+                        indexable.AddProperty (Property.NewUnsearched ("fixme:folder", folder));
 			indexable.ContentUri = file_uri;
 
 			return indexable;
@@ -395,35 +395,41 @@ namespace Beagle.Daemon.KMailQueryable {
 			indexable.MimeType = "message/rfc822";
 			indexable.CacheContent = false;
 
-			indexable.AddProperty (Property.NewKeyword ("fixme:client", "kmail"));
-			indexable.AddProperty (Property.NewKeyword ("fixme:account", account_name));
-                        indexable.AddProperty (Property.NewKeyword ("fixme:folder", folder_name));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:client", "kmail"));
+			indexable.AddProperty (Property.NewUnsearched ("fixme:account", account_name));
+                        indexable.AddProperty (Property.NewUnsearched ("fixme:folder", folder_name));
 
 			GMime.InternetAddressList addrs;
 
 			addrs = message.GetRecipients (GMime.Message.RecipientType.To);
 			foreach (GMime.InternetAddress ia in addrs) {
-				if (folder_name == Queryable.SentMailFolderName)
+				if (folder_name == Queryable.SentMailFolderName && ia.AddressType != GMime.InternetAddressType.Group)
 					indexable.AddProperty (Property.NewKeyword ("fixme:sentTo", ia.Addr));
 			}
 			addrs.Dispose ();
 
 			addrs = message.GetRecipients (GMime.Message.RecipientType.Cc);
 			foreach (GMime.InternetAddress ia in addrs) {
-				if (folder_name == Queryable.SentMailFolderName)
+				if (folder_name == Queryable.SentMailFolderName && ia.AddressType != GMime.InternetAddressType.Group)
 					indexable.AddProperty (Property.NewKeyword ("fixme:sentTo", ia.Addr));
 			}
 			addrs.Dispose ();
 
 			addrs = GMime.InternetAddressList.ParseString (GMime.Utils.HeaderDecodePhrase (message.Sender));
 			foreach (GMime.InternetAddress ia in addrs) {
-				if (folder_name != Queryable.SentMailFolderName)
+				if (folder_name != Queryable.SentMailFolderName && ia.AddressType != GMime.InternetAddressType.Group)
 					indexable.AddProperty (Property.NewKeyword ("fixme:gotFrom", ia.Addr));
 			}
 			addrs.Dispose ();
 
 			if (folder_name == Queryable.SentMailFolderName)
 				indexable.AddProperty (Property.NewFlag ("fixme:isSent"));
+			else {
+				string kmail_msg_sent = message.GetHeader ("X-KMail-Link-Type");
+				if (kmail_msg_sent == "reply")
+					indexable.AddProperty (Property.NewFlag ("fixme:isSent"));
+			}
+				
 // no need to store date again, use the issent flag to determine if the date is sentdate or not			
 #if false
 			if (folder_name == Queryable.SentMailFolderName)
