@@ -26,7 +26,7 @@ namespace Lucene.Net.Index
 	/// <summary> FIXME: Describe class <code>SegmentReader</code> here.
 	/// 
 	/// </summary>
-	/// <version>  $Id: SegmentReader.cs,v 1.3 2005/10/06 19:29:55 dsd Exp $
+	/// <version>  $Id: SegmentReader.cs,v 1.5 2006/04/03 17:12:17 joeshaw Exp $
 	/// </version>
 	class SegmentReader : IndexReader
 	{
@@ -36,8 +36,10 @@ namespace Lucene.Net.Index
 		private FieldsReader fieldsReader;
 		
 		internal TermInfosReader tis;
-        internal TermVectorsReader termVectorsReaderOrig = null;
-        internal System.LocalDataStoreSlot termVectorsLocal = System.Threading.Thread.AllocateDataSlot();
+		internal TermVectorsReader termVectorsReaderOrig = null;
+
+		[ThreadStatic]
+		private TermVectorsReader tvReader;
 		
 		internal BitVector deletedDocs = null;
 		private bool deletedDocsDirty = false;
@@ -172,19 +174,6 @@ namespace Lucene.Net.Index
 			}
 		}
 		
-        ~SegmentReader()
-        {
-            // patch for pre-1.4.2 JVMs, whose ThreadLocals leak
-            try
-            {            
-                System.Threading.Thread.SetData(termVectorsLocal, null);     // {{Aroush-1.9}} is this required for .NET ?!
-            }
-            catch (Exception ex)
-            {
-                // System.Console.WriteLine(ex.Message);
-            }
-        }
-		
 		protected internal override void  DoCommit()
 		{
 			if (deletedDocsDirty)
@@ -609,11 +598,9 @@ namespace Lucene.Net.Index
         /// </returns>
         private TermVectorsReader GetTermVectorsReader()
         {
-            TermVectorsReader tvReader = (TermVectorsReader) System.Threading.Thread.GetData(termVectorsLocal);
             if (tvReader == null)
             {
                 tvReader = (TermVectorsReader) termVectorsReaderOrig.Clone();
-                System.Threading.Thread.SetData(termVectorsLocal, tvReader);
             }
             return tvReader;
         }
